==> ingdao-0.0.6.tar.gz: lib/dataflow/entity/dfdbentity.dart <==
import 'package:meta/meta.dart';
import 'dfbaseentity.dart';
import '../field/dfdbfield.dart';
import '../field/dfbasefield.dart';
import '../control/dfquerycriteria.dart';
import '../control/dfquerycriteriagroup.dart';
import '../field/dffieldtype.dart';
import 'package:object_mapper/object_mapper.dart';

abstract class DfDbEntity extends DfBaseEntity<DfDbField> {

  DfDbEntity({@required String name}) : super(entityName: name);

   List<DfDbField> getJoinKeyFields() {
    return fields().where((f) => f.joinKey).toList();
  }

  List<DfDbField> getPrimaryKeyFields() {
    return fields().where((f) => f.primaryKey).toList();
  }

  DfQueryCriteriaGroup getPrimaryKeyDaoCriteriaList() {
    List<DfQueryCriteria> criGroupArr = List<DfQueryCriteria>();
    getPrimaryKeyFields().forEach((field) {
      criGroupArr.add(DfQueryCriteria(field: field, oper: OperType.eq, values: [field.value]));
    });
    return DfQueryCriteriaGroup(criterias: criGroupArr);

  }

  String toPrimaryKeyStr() {
    String result = "";
    getPrimaryKeyFields().forEach((item) {
      if (result.length > 0) {
        result = "$result, ";        
      }
      String fName = item.name;
      result = "$result$fName";
    });
    if (result.length > 0) {
      return ", PRIMARY KEY ($result)";
    }
    return '';
  }

  String genAlterTblAddFieldStr(DfDbField field) {
    return "ALTER TABLE $entityName ADD ${field.toCreateFieldStr()}";
  }

  String toCreateEntityStr() {
    String result = "";
    fields().forEach((field) {
      if (field.displayOnly == null || !field.displayOnly) {
        if (result.length > 0) {
          result = "$result, ";
        }
        String fieldCreation = field.toCreateFieldStr();
        result = "$result$fieldCreation";
      }
    });
    String priKeyStr = toPrimaryKeyStr();
    return "CREATE TABLE $entityName($result$priKeyStr)";
  }

  DfBaseField getSelectQueryCountField() {
    return DfDbField(entity: this, name: "count(*)", primaryKey: false, joinKey: false, fieldType: DfFieldType.integer());
  }

  @override
  void doYourJsonMap(Mapper map, List<DfDbField> fields) { 
    //print("call db doYourJsonMap");   
    for (int i = 0; i < fields.length; i++) {
      if (fields[i].getObjectValue != null && fields[i].setObjectValue != null) {
        map(fields[i].getSelectQueryAlias(), fields[i].getObjectValue(), (v) => fields[i].setObjectValue(v), fields[i].getTransform());
      }
    }
  }

}

==> ingdao-0.0.19.tar.gz: lib/dataflow/entity/dfdbentity.dart <==
import 'package:meta/meta.dart';
import 'dfbaseentity.dart';
import '../field/dfdbfield.dart';
import '../field/dfbasefield.dart';
import '../control/dfquerycriteria.dart';
import '../control/dfquerycriteriagroup.dart';
import '../field/dffieldtype.dart';
import 'package:object_mapper/object_mapper.dart';

abstract class DfDbEntity extends DfBaseEntity<DfDbField> {

  DfDbEntity({@required String name}) : super(entityName: name);

   List<DfDbField> getJoinKeyFields() {
    return fields().where((f) => f.joinKey).toList();
  }

  List<DfDbField> getPrimaryKeyFields() {
    return fields().where((f) => f.primaryKey).toList();
  }

  DfQueryCriteriaGroup getPrimaryKeyDaoCriteriaList() {
    List<DfQueryCriteria> criGroupArr = List<DfQueryCriteria>();
    getPrimaryKeyFields().forEach((field) {
      criGroupArr.add(DfQueryCriteria(field: field, oper: OperType.eq, values: [field.value]));
    });
    return DfQueryCriteriaGroup(criterias: criGroupArr);

  }

  String toPrimaryKeyStr() {
    String result = "";
    getPrimaryKeyFields().forEach((item) {
      if (result.length > 0) {
        result = "$result, ";        
      }
      String fName = item.name;
      result = "$result$fName";
    });
    if (result.length > 0) {
      return ", PRIMARY KEY ($result)";
    }
    return '';
  }

  String genAlterTblAddFieldStr(DfDbField field) {
    return "ALTER TABLE $entityName ADD ${field.toCreateFieldStr()}";
  }

  String toCreateEntityStr() {
    String result = "";
    fields().forEach((field) {
      if (field.displayOnly == null || !field.displayOnly) {
        if (result.length > 0) {
          result = "$result, ";
        }
        String fieldCreation = field.toCreateFieldStr();
        result = "$result$fieldCreation";
      }
    });
    String priKeyStr = toPrimaryKeyStr();
    return "CREATE TABLE $entityName($result$priKeyStr)";
  }

  DfBaseField getSelectQueryCountField() {
    return DfDbField(entity: this, name: "count(*)", primaryKey: false, joinKey: false, fieldType: DfFieldType.integer());
  }

  @override
  void doYourJsonMap(Mapper map, List<DfDbField> fields) { 
    //print("call db doYourJsonMap");  
    List<DfDbField> customFields = [];  
    for (int i = 0; i < fields.length; i++) {
      if (fields[i].fieldType.type != FieldType.custom && fields[i].getObjectValue != null && fields[i].setObjectValue != null) {
        map(fields[i].getSelectQueryAlias(), fields[i].getObjectValue(), (v) => fields[i].setObjectValue(v), fields[i].getTransform());
      }
      else if (fields[i].getObjectValue != null && fields[i].setObjectValue != null) {
        customFields.add(fields[i]);
      }
    }
    customFieldJsonMap(map, customFields);
  }

}
